summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorwang_zhiqiang <wang_zhiqiang@dl.cn.nexty-ele.com>2018-11-06 10:20:51 +0800
committerwang_zhiqiang <wang_zhiqiang@dl.cn.nexty-ele.com>2018-11-06 11:09:59 +0800
commit6de11471bf8cc70c5a11f947dea5a2afc9bef716 (patch)
treef2aa289f9d658c83bdde75c331da6ce4b2a8b0b9
parent0d7f000588954006d4687c97c19b424769189f9f (diff)
use appid instead of appname in "tap_shortcut"
Now In homescreen-service used application_id to identify different application, so use appid instead of appname in "tap_shortcut" parameter. Bug-AGL: SPEC-1764 Change-Id: Iccb40a38c7e0fa39c8727582c50e6003b90dc89d Signed-off-by: wang_zhiqiang <wang_zhiqiang@dl.cn.nexty-ele.com>
-rw-r--r--src/qlibhomescreen.cpp10
-rw-r--r--src/qlibhomescreen.h2
2 files changed, 6 insertions, 6 deletions
diff --git a/src/qlibhomescreen.h b/src/qlibhomescreen.h
index cc0f12a..bf43963 100644
--- a/src/qlibhomescreen.h
+++ b/src/qlibhomescreen.h
@@ -43,7 +43,7 @@ public:
Q_INVOKABLE int onScreenMessage(const QString &message);
Q_INVOKABLE int subscribe(const QString &eventName);
Q_INVOKABLE int unsubscribe(const QString &eventName);
- Q_INVOKABLE void tapShortcut(QString application_name);
+ Q_INVOKABLE void tapShortcut(QString application_id);
signals:
diff --git a/src/qlibhomescreen.cpp b/src/qlibhomescreen.cpp
index 13093c3..aded770 100644
--- a/src/qlibhomescreen.cpp
+++ b/src/qlibhomescreen.cpp
@@ -24,7 +24,7 @@ using namespace std;
#define _REQ_POPUP_MESSAGE "on_screen_message"
#define _TAPSHORTCUT "tap_shortcut"
#define _KEY_DATA "data"
-#define _KEY_APPLICATION_DATA "application_name"
+#define _KEY_APPLICATION_DATA "application_id"
#define _KEY_REPLY_MESSAGE "reply_message"
#define _KEY_REQUEST_MESSAGE "display_message"
@@ -169,14 +169,14 @@ void QLibHomeScreen::set_event_handler(enum QEventType et, handler_fun f)
* tapShortcut function
*
* #### Parameters
* - application_name : tapped application name
*
* #### Return
* - None.
*
*/
-void QLibHomeScreen::tapShortcut(QString application_name)
+void QLibHomeScreen::tapShortcut(QString application_id)
{
- HMI_DEBUG("qlibhomescreen","tapShortcut %s", application_name.toStdString().c_str());
- this->mp_hs->tapShortcut(application_name.toStdString().c_str());
+ HMI_DEBUG("qlibhomescreen","tapShortcut %s", application_id.toStdString().c_str());
+ this->mp_hs->tapShortcut(application_id.toStdString().c_str());
} \ No newline at end of file
@@ -169,14 +169,14 @@ void QLibHomeScreen::set_event_handler(enum QEventType et, handler_fun f)
*
* #### Parameters
- * - application_name : tapped application name
+ * - application_id : tapped application id
*
* #### Return